@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION = '2.24';
+$Map::Tube::VERSION = '2.25';
 
 use 5.006;
 use XML::Simple;
@@ -20,7 +20,7 @@ Map::Tube - Core library as Role (Moo) to process map data.
 
 =head1 VERSION
 
-Version 2.24
+Version 2.25
 
 =head1 DESCRIPTION
 
@@ -268,6 +268,10 @@ sub _is_number {
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/Map-Tube>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-map-tube at rt.cpan.org>,  or
