@@ -1,6 +1,6 @@
 package Map::Tube::Exception;
 
-$Map::Tube::Exception::VERSION = '2.24';
+$Map::Tube::Exception::VERSION = '2.25';
 
 use 5.006;
 use Moo;
@@ -13,7 +13,7 @@ Map::Tube::Exception - Interface to exception class used by Map::Tube.
 
 =head1 VERSION
 
-Version 2.24
+Version 2.25
 
 =cut
 
@@ -37,6 +37,10 @@ sub as_string {
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/Map-Tube>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-map-tube at rt.cpan.org>,  or
