@@ -1,9 +1,10 @@
 package Map::Tube::Node;
 
-$Map::Tube::Node::VERSION = '2.24';
+$Map::Tube::Node::VERSION = '2.25';
 
 use 5.006;
 use Moo;
+use namespace::clean;
 
 =head1 NAME
 
@@ -11,7 +12,7 @@ Map::Tube::Node - Class to represent the node in the map.
 
 =head1 VERSION
 
-Version 2.24
+Version 2.25
 
 =cut
 
@@ -32,6 +33,10 @@ sub as_string {
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/Map-Tube>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-map-tube at rt.cpan.org>,  or
